==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/PolarLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { runOn, enumGetBox, markType, markDep } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var PolarLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeries, _super);
    function PolarLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarLineSeries.$;
        return _this;
    }
    PolarLineSeries.prototype.get_ex = function () {
        return true;
    };
    PolarLineSeries.prototype.cg = function () {
        return new PolarLineSeriesView(this);
    };
    PolarLineSeries.prototype.o0 = function (a) {
        _super.prototype.o0.call(this, a);
        this.zm = a;
    };
    PolarLineSeries.prototype.zk = function (a) {
        var b = a;
        b.c8();
    };
    PolarLineSeries.prototype.zl = function (a, b) {
        var c = b;
        c.c9(a.m, this.hj);
        this.v3.az(this, this.wq(), runOn(this, this.vg));
        var d = false;
        var e = this.v3.b;
        if (e != null) {
            d = true;
        }
        if (d) {
            this.x5(-1, this.wc.count, b.q);
        }
        this.v3.ad(b.db, true, false, true, false);
    };
    PolarLineSeries.prototype.zc = function () {
        return this.zn;
    };
    PolarLineSeries.prototype.o8 = function (a, b, c, d) {
        _super.prototype.o8.call(this, a, b, c, d);
        switch (b) {
            case PolarLineSeries.$$p[0]:
                this.pp(false);
                this.ol();
                break;
        }
    };
    PolarLineSeries.$t = markType(PolarLineSeries, 'PolarLineSeries', PolarLineSeriesBase.$);
    PolarLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, PolarLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:zn:zp', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarLineSeries;
}(PolarLineSeriesBase));
export { PolarLineSeries };
/**
 * @hidden
 */
var PolarLineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeriesView, _super);
    function PolarLineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c7 = null;
        _this.db = new Path();
        _this.da = new Path();
        _this.c7 = a;
        return _this;
    }
    PolarLineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.b4.ua = Defaults.e;
        }
    };
    PolarLineSeriesView.prototype.c8 = function () {
        this.db.an = null;
        this.da.an = null;
        this.as();
    };
    PolarLineSeriesView.prototype.c9 = function (a, b) {
        this.c7.y9.d(this.db, a, b);
        this.as();
    };
    PolarLineSeriesView.prototype.bd = function () {
        _super.prototype.bd.call(this);
    };
    PolarLineSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        var a = this.br();
        this.da.an = this.db.an;
        this.da._stroke = a;
        this.da.ad = this.e.hk + 3;
    };
    PolarLineSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.da);
            }
            else {
                a.t(this.db);
            }
        }
    };
    PolarLineSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.a9.exportPathData(a, this.db, "polarShape", ["Main"]);
    };
    PolarLineSeriesView.$t = markType(PolarLineSeriesView, 'PolarLineSeriesView', PolarLineSeriesBaseView.$);
    return PolarLineSeriesView;
}(PolarLineSeriesBaseView));
export { PolarLineSeriesView };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/PolarLineSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PolarLineSeriesBase } from "./PolarLineSeriesBase";
import { UnknownValuePlotting_$type } from "igniteui-react-core";
import { DependencyProperty } from "igniteui-react-core";
import { runOn, enumGetBox, markType, markDep } from "igniteui-react-core";
import { Path } from "igniteui-react-core";
import { PropertyMetadata } from "igniteui-react-core";
import { PolarLineSeriesBaseView } from "./PolarLineSeriesBaseView";
import { Defaults } from "./Defaults";
/**
 * @hidden
 */
var PolarLineSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeries, _super);
    function PolarLineSeries() {
        var _this = _super.call(this) || this;
        _this.ab = PolarLineSeries.$;
        return _this;
    }
    PolarLineSeries.prototype.bj = function () {
        return new PolarLineSeries();
    };
    PolarLineSeries.prototype.get_fj = function () {
        return true;
    };
    PolarLineSeries.prototype.cr = function () {
        return new PolarLineSeriesView(this);
    };
    PolarLineSeries.prototype.qz = function (a) {
        _super.prototype.qz.call(this, a);
        this.acp = a;
    };
    PolarLineSeries.prototype.acn = function (a) {
        var b = a;
        b.da();
    };
    PolarLineSeries.prototype.aco = function (a, b) {
        var c = b;
        c.db(a.m, this.ic);
        this.y0.az(this, this.zs(), runOn(this, this.yi));
        var d = false;
        var e = this.y0.b;
        if (e != null) {
            d = true;
        }
        if (d) {
            this.aa7(-1, this.ze.count, b.q);
        }
        this.y0.ad(b.dd, true, false, true, false);
    };
    PolarLineSeries.prototype.acf = function () {
        return this.acq;
    };
    PolarLineSeries.prototype.q7 = function (a, b, c, d) {
        _super.prototype.q7.call(this, a, b, c, d);
        switch (b) {
            case PolarLineSeries.$$p[0]:
                this.rp(false);
                this.qj();
                break;
        }
    };
    PolarLineSeries.$t = markType(PolarLineSeries, 'PolarLineSeries', PolarLineSeriesBase.$);
    PolarLineSeries.$$p = markDep(DependencyProperty, PropertyMetadata, PolarLineSeries, 'raisePropertyChanged', ['UnknownValuePlotting:acq:acs', [UnknownValuePlotting_$type, enumGetBox(UnknownValuePlotting_$type, 1)]]);
    return PolarLineSeries;
}(PolarLineSeriesBase));
export { PolarLineSeries };
/**
 * @hidden
 */
var PolarLineSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(PolarLineSeriesView, _super);
    function PolarLineSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.c9 = null;
        _this.dd = new Path();
        _this.dc = new Path();
        _this.c9 = a;
        return _this;
    }
    PolarLineSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.b4.w5 = Defaults.e;
        }
    };
    PolarLineSeriesView.prototype.da = function () {
        this.dd.an = null;
        this.dc.an = null;
        this.as();
    };
    PolarLineSeriesView.prototype.db = function (a, b) {
        this.c9.acc.d(this.dd, a, b);
        this.as();
    };
    PolarLineSeriesView.prototype.bd = function () {
        _super.prototype.bd.call(this);
    };
    PolarLineSeriesView.prototype.be = function () {
        _super.prototype.be.call(this);
        var a = this.br();
        this.dc.an = this.dd.an;
        this.dc._stroke = a;
        this.dc.ad = this.e.id + 3;
    };
    PolarLineSeriesView.prototype.a8 = function (a, b) {
        _super.prototype.a8.call(this, a, b);
        if (a.d) {
            if (b) {
                a.t(this.dc);
            }
            else {
                a.t(this.dd);
            }
        }
    };
    PolarLineSeriesView.prototype.an = function (a) {
        _super.prototype.an.call(this, a);
        this.e.bc.exportPathData(a, this.dd, "polarShape", ["Main"]);
    };
    PolarLineSeriesView.$t = markType(PolarLineSeriesView, 'PolarLineSeriesView', PolarLineSeriesBaseView.$);
    return PolarLineSeriesView;
}(PolarLineSeriesBaseView));
export { PolarLineSeriesView };
